==> lima-swing-0.5-sources.jar: org/chorem/lima/ui/entrybooksreports/EntryBooksReportsViewHandler.java <==
/*
 * #%L
 * Lima Swing
 * 
 * $Id: EntryBooksReportsViewHandler.java 3229 2011-07-18 14:17:31Z vsalaun $
 * $HeadURL: http://svn.chorem.org/svn/lima/tags/lima-0.5/lima-swing/src/main/java/org/chorem/lima/ui/entrybooksreports/EntryBooksReportsViewHandler.java $
 * %%
 * Copyright (C) 2008 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package org.chorem.lima.ui.entrybooksreports;

import static org.nuiton.i18n.I18n._;
import java.awt.Desktop;
import java.io.IOException;
import java.math.BigDecimal;
import java.net.URI;
import java.net.URISyntaxException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import javax.swing.JOptionPane;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.chorem.lima.LimaConfig;
import org.chorem.lima.beans.ReportsDatas;
import org.chorem.lima.business.DocumentServiceMonitorable;
import org.chorem.lima.business.FinancialTransactionServiceMonitorable;
import org.chorem.lima.business.FiscalPeriodServiceMonitorable;
import org.chorem.lima.business.HttpServerServiceMonitorable;
import org.chorem.lima.business.ImportServiceMonitorable;
import org.chorem.lima.business.LimaException;
import org.chorem.lima.business.ReportServiceMonitorable;
import org.chorem.lima.business.ServiceListener;
import org.chorem.lima.business.utils.DocumentsEnum;
import org.chorem.lima.business.utils.FormatsEnum;
import org.chorem.lima.entity.EntryBook;
import org.chorem.lima.entity.FiscalPeriod;
import org.chorem.lima.service.LimaServiceFactory;
import org.chorem.lima.util.ErrorHelper;


/**
 * Handler associated with accounts reports view.
 * By : $Author: vsalaun $
 */
public class EntryBooksReportsViewHandler implements ServiceListener {

    protected EntryBooksReportsView view;
    
    protected EntryBooksReportsTable table;
    
    protected EntryBooksReportsTableModel tableModel;
    
    /** log. */
    private static final Log log = LogFactory.getLog(EntryBooksReportsViewHandler.class);
    
    /** Services. */
    protected ReportServiceMonitorable reportService;
    protected DocumentServiceMonitorable documentService;
    protected FiscalPeriodServiceMonitorable fiscalPeriodService;
    
    /** Account. */
    protected EntryBook selectedEntryBook;
    
    /** Begin Date. */
    protected Date selectedBeginDate;
    
    /** EndDate. */
    protected Date selectedEndDate;
    
    protected int port;
    
    private static SimpleDateFormat dateFormat =
        new SimpleDateFormat("yyyy-MM-dd");
        
    protected EntryBooksReportsViewHandler(EntryBooksReportsView view) {
        this.view = view;
        
        reportService =
            LimaServiceFactory.getInstance().getService(
                    ReportServiceMonitorable.class);
        port = LimaServiceFactory.getInstance().getService(
                HttpServerServiceMonitorable.class).getHttpPort();
        documentService =
            LimaServiceFactory.getInstance().getService(
                    DocumentServiceMonitorable.class);
        fiscalPeriodService =
            LimaServiceFactory.getInstance().getService(
                    FiscalPeriodServiceMonitorable.class);
        LimaServiceFactory.getInstance().getService(
                ImportServiceMonitorable.class).addListener(this);
        LimaServiceFactory.getInstance().getService(
                FinancialTransactionServiceMonitorable.class).addListener(this);
    }
    
    public void setBeginDate(Date date){
        selectedBeginDate = date;
        refresh();
    }
    
    public void setEndDate(Date date){
        selectedEndDate = date;
        refresh();
    }
    

    public void setEntryBook(EntryBook entryBook) {
        selectedEntryBook = entryBook;
        refresh();
    }
    
    public ReportsDatas getDataList(){
        ReportsDatas results = null;
        if (selectedEntryBook != null){
            try {
                results =
                    reportService.generateEntryBooksReports(
                            selectedEntryBook, selectedBeginDate, selectedEndDate);
            }
            catch (LimaException eee) {
                if (log.isErrorEnabled()) {
                    log.debug("Can't update model", eee);
                }
                ErrorHelper.showErrorDialog(_("lima.entrybooksreports.listerror"), eee);
            }    
        }
        return results;
    }
    
    public void refresh(){
        
        if (selectedBeginDate != null && selectedEndDate != null && selectedEntryBook != null){
            tableModel = view.getModelTable();
            
            ReportsDatas datasList = getDataList();
    
            tableModel.refresh(datasList); 
    
         /**
          *  set text and amounts of labels credit, debit, solde
         */
            
            if (datasList != null){
                // set amounts credit, debit and solde
                view.amountCreditLabel.setText(
                        String.valueOf(datasList.getAmountCredit()));
                view.amountDebitLabel.setText(
                        String.valueOf(datasList.getAmountDebit()));            
                BigDecimal amountSolde = datasList.getAmountSolde();
                view.amountSoldeLabel.setText(String.valueOf(amountSolde));
                
                if (amountSolde == BigDecimal.ZERO){
                    view.soldeLabel.setText(_("lima.common.solde"));
                }
                else {
                    // set label solde: credit or debit
                    if (datasList.getSoldeDebit()) {
                        view.soldeLabel.setText(_("lima.common.soldedebit"));
                    }
                    else {
                        view.soldeLabel.setText(_("lima.common.soldecredit"));
                    }
                }
            }
        }
    }
    
    
    
    public void createDocument() {
        
        if (selectedBeginDate != null && selectedEndDate != null){
            
            //looks for all blocked fiscal periods
            List<FiscalPeriod> blockedFiscalPeriods = new ArrayList<FiscalPeriod>();
            try {
                blockedFiscalPeriods = fiscalPeriodService.getAllBlockedFiscalPeriods();
            } catch (LimaException eee) {
                if (log.isErrorEnabled()) {
                    log.debug("Enable to create document ", eee);
                }
                ErrorHelper.showErrorDialog(_("lima.entrybooksreports.documentcreationerror"), eee);
            }
        
            //tells if the fiscaPeriod as been found and is blocked
            boolean error = true;
        
            for (FiscalPeriod blockedFiscalPeriod : blockedFiscalPeriods) {
                if (blockedFiscalPeriod.getBeginDate().equals(selectedBeginDate)
                        && blockedFiscalPeriod.getEndDate().equals(selectedEndDate)
                        && blockedFiscalPeriod.getLocked()) {
                    error = false;
                }
            }
        
            //shows error message to user if the fiscalPeriod is unblocked
            if (error) {
                JOptionPane.showMessageDialog(
                        view,
                        _("lima.entrybooksreports.documentcreationfiscalerror"),
                        _("lima.common.error"),
                        JOptionPane.ERROR_MESSAGE);
            } else {
            
                FormatsEnum selectedEnum = (FormatsEnum) view.getDocumentEditor().getSelectedItem();
                String address = LimaConfig.getInstance().getHostAdress();
                
                try {
                    String url = "http://"+address+":"+port+"/?beginDate="
                    + dateFormat.format(selectedBeginDate)
                    + "&endDate="+dateFormat.format(selectedEndDate)
                    + "&format="+selectedEnum.getExtension()+"&model="
                    + DocumentsEnum.ENTRYBOOKS.getFileName();
                    Desktop.getDesktop().browse(new URI(url));
                    
                    String url2 = "http://"+address+":"+port+"/?beginDate="
                    + dateFormat.format(selectedBeginDate)
                    + "&endDate="+dateFormat.format(selectedEndDate)
                    + "&format="+selectedEnum.getExtension()+"&model="
                    + DocumentsEnum.GENERAL_ENTRYBOOK.getFileName();
                    Desktop.getDesktop().browse(new URI(url2)); 
                
                } catch (IOException e) {
                    log.error("Can't open browser", e);
                } catch (URISyntaxException e) {
                    log.error("Can't create news URI", e);
                }
            }
        }
    }
    
    @Override
    public void notifyMethod(String serviceName, String methodeName) {
        if (serviceName.contains("FinancialTransaction") || methodeName.contains("importEntryBook") || methodeName.contains("importAll")){
            refresh();
        }
    }
    
}

==> lima-swing-0.5.1-sources.jar: org/chorem/lima/ui/entrybooksreports/EntryBooksReportsViewHandler.java <==
/*
 * #%L
 * Lima Swing
 * 
 * $Id: EntryBooksReportsViewHandler.java 3278 2011-08-16 14:09:44Z tchemit $
 * $HeadURL: http://svn.chorem.org/svn/lima/tags/lima-0.5.1/lima-swing/src/main/java/org/chorem/lima/ui/entrybooksreports/EntryBooksReportsViewHandler.java $
 * %%
 * Copyright (C) 2008 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package org.chorem.lima.ui.entrybooksreports;

import static org.nuiton.i18n.I18n._;
import java.awt.Desktop;
import java.io.IOException;
import java.math.BigDecimal;
import java.net.URI;
import java.net.URISyntaxException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import javax.swing.JOptionPane;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.chorem.lima.LimaConfig;
import org.chorem.lima.beans.ReportsDatas;
import org.chorem.lima.business.DocumentServiceMonitorable;
import org.chorem.lima.business.FinancialTransactionServiceMonitorable;
import org.chorem.lima.business.FiscalPeriodServiceMonitorable;
import org.chorem.lima.business.HttpServerServiceMonitorable;
import org.chorem.lima.business.ImportServiceMonitorable;
import org.chorem.lima.business.LimaException;
import org.chorem.lima.business.ReportServiceMonitorable;
import org.chorem.lima.business.ServiceListener;
import org.chorem.lima.business.utils.DocumentsEnum;
import org.chorem.lima.business.utils.FormatsEnum;
import org.chorem.lima.entity.EntryBook;
import org.chorem.lima.entity.FiscalPeriod;
import org.chorem.lima.service.LimaServiceFactory;
import org.chorem.lima.util.ErrorHelper;


/**
 * Handler associated with accounts reports view.
 * By : $Author: tchemit $
 */
public class EntryBooksReportsViewHandler implements ServiceListener {

    protected EntryBooksReportsView view;
    
    protected EntryBooksReportsTable table;
    
    protected EntryBooksReportsTableModel tableModel;
    
    /** log. */
    private static final Log log = LogFactory.getLog(EntryBooksReportsViewHandler.class);
    
    /** Services. */
    protected ReportServiceMonitorable reportService;
    protected DocumentServiceMonitorable documentService;
    protected FiscalPeriodServiceMonitorable fiscalPeriodService;
    
    /** Account. */
    protected EntryBook selectedEntryBook;
    
    /** Begin Date. */
    protected Date selectedBeginDate;
    
    /** EndDate. */
    protected Date selectedEndDate;
    
    protected int port;
    
    private static SimpleDateFormat dateFormat =
        new SimpleDateFormat("yyyy-MM-dd");
        
    protected EntryBooksReportsViewHandler(EntryBooksReportsView view) {
        this.view = view;
        
        reportService =
            LimaServiceFactory.getInstance().getService(
                    ReportServiceMonitorable.class);
        port = LimaServiceFactory.getInstance().getService(
                HttpServerServiceMonitorable.class).getHttpPort();
        documentService =
            LimaServiceFactory.getInstance().getService(
                    DocumentServiceMonitorable.class);
        fiscalPeriodService =
            LimaServiceFactory.getInstance().getService(
                    FiscalPeriodServiceMonitorable.class);
        LimaServiceFactory.getInstance().getService(
                ImportServiceMonitorable.class).addListener(this);
        LimaServiceFactory.getInstance().getService(
                FinancialTransactionServiceMonitorable.class).addListener(this);
    }
    
    public void setBeginDate(Date date){
        selectedBeginDate = date;
        refresh();
    }
    
    public void setEndDate(Date date){
        selectedEndDate = date;
        refresh();
    }
    

    public void setEntryBook(EntryBook entryBook) {
        selectedEntryBook = entryBook;
        refresh();
    }
    
    public ReportsDatas getDataList(){
        ReportsDatas results = null;
        if (selectedEntryBook != null){
            try {
                results =
                    reportService.generateEntryBooksReports(
                            selectedEntryBook, selectedBeginDate, selectedEndDate);
            }
            catch (LimaException eee) {
                if (log.isErrorEnabled()) {
                    log.debug("Can't update model", eee);
                }
                ErrorHelper.showErrorDialog(_("lima.entrybooksreports.listerror"), eee);
            }    
        }
        return results;
    }
    
    public void refresh(){
        
        if (selectedBeginDate != null && selectedEndDate != null && selectedEntryBook != null){
            tableModel = view.getModelTable();
            
            ReportsDatas datasList = getDataList();
    
            tableModel.refresh(datasList); 
    
         /**
          *  set text and amounts of labels credit, debit, solde
         */
            
            if (datasList != null){
                // set amounts credit, debit and solde
                view.amountCreditLabel.setText(
                        String.valueOf(datasList.getAmountCredit()));
                view.amountDebitLabel.setText(
                        String.valueOf(datasList.getAmountDebit()));            
                BigDecimal amountSolde = datasList.getAmountSolde();
                view.amountSoldeLabel.setText(String.valueOf(amountSolde));
                
                if (amountSolde == BigDecimal.ZERO){
                    view.soldeLabel.setText(_("lima.common.solde"));
                }
                else {
                    // set label solde: credit or debit
                    if (datasList.getSoldeDebit()) {
                        view.soldeLabel.setText(_("lima.common.soldedebit"));
                    }
                    else {
                        view.soldeLabel.setText(_("lima.common.soldecredit"));
                    }
                }
            }
        }
    }
    
    
    
    public void createDocument() {
        
        if (selectedBeginDate != null && selectedEndDate != null){
            
            //looks for all blocked fiscal periods
            List<FiscalPeriod> blockedFiscalPeriods = new ArrayList<FiscalPeriod>();
            try {
                blockedFiscalPeriods = fiscalPeriodService.getAllBlockedFiscalPeriods();
            } catch (LimaException eee) {
                if (log.isErrorEnabled()) {
                    log.debug("Enable to create document ", eee);
                }
                ErrorHelper.showErrorDialog(_("lima.entrybooksreports.documentcreationerror"), eee);
            }
        
            //tells if the fiscaPeriod as been found and is blocked
            boolean error = true;
        
            for (FiscalPeriod blockedFiscalPeriod : blockedFiscalPeriods) {
                if (blockedFiscalPeriod.getBeginDate().equals(selectedBeginDate)
                        && blockedFiscalPeriod.getEndDate().equals(selectedEndDate)
                        && blockedFiscalPeriod.getLocked()) {
                    error = false;
                }
            }
        
            //shows error message to user if the fiscalPeriod is unblocked
            if (error) {
                JOptionPane.showMessageDialog(
                        view,
                        _("lima.entrybooksreports.documentcreationfiscalerror"),
                        _("lima.common.error"),
                        JOptionPane.ERROR_MESSAGE);
            } else {
            
                FormatsEnum selectedEnum = (FormatsEnum) view.getDocumentEditor().getSelectedItem();
                String address = LimaConfig.getInstance().getHostAdress();
                
                try {
                    String url = "http://"+address+":"+port+"/?beginDate="
                    + dateFormat.format(selectedBeginDate)
                    + "&endDate="+dateFormat.format(selectedEndDate)
                    + "&format="+selectedEnum.getExtension()+"&model="
                    + DocumentsEnum.ENTRYBOOKS.getFileName();
                    Desktop.getDesktop().browse(new URI(url));
                    
                    String url2 = "http://"+address+":"+port+"/?beginDate="
                    + dateFormat.format(selectedBeginDate)
                    + "&endDate="+dateFormat.format(selectedEndDate)
                    + "&format="+selectedEnum.getExtension()+"&model="
                    + DocumentsEnum.GENERAL_ENTRYBOOK.getFileName();
                    Desktop.getDesktop().browse(new URI(url2)); 
                
                } catch (IOException e) {
                    log.error("Can't open browser", e);
                } catch (URISyntaxException e) {
                    log.error("Can't create news URI", e);
                }
            }
        }
    }
    
    @Override
    public void notifyMethod(String serviceName, String methodeName) {
        if (serviceName.contains("FinancialTransaction") || methodeName.contains("importEntryBook") || methodeName.contains("importAll")){
            refresh();
        }
    }
    
}
